package cinema;

public class SalaCinema
{
	Poltrona[] poltrone;
	int prenotati;

	/**
	* Costruttore classe SalaCinema, richiede il numero di posti della sala.
	*/
	public SalaCinema(int posti)
	{
		poltrone = new Poltrona[posti];
		int i = 0;
		for(i=0;i<posti;i++)
		{
			poltrone[i] = new Poltrona();
		}
		prenotati = 0;
	}

	/**
	* Costruttore di default classe SalaCinema, imposta il numero di posti della
	*	sala al valore 100.
	*/
	public SalaCinema()
	{
		this(100);
	}

	/**
	* Prenota una poltrona a nome ilPrenotante. Se non ci sono posti liberi
	* o se esiste gia' una prenotazione a nome ilPrenotante fallisce.
	* Ritorna il numero di posto prenotato in caso di successo, -1 in caso di
	* sala piena, -2 in caso di precedente prenotazione.
	*/
	public int prenota(String ilPrenotante)
	{
		//Controllo se il signore ha gia' una prenotazione
		if(esistePrenotazione(ilPrenotante) != -1)
		{
			return -2;
		}

		//controllo se la sala e' piena
		if(prenotati == poltrone.length)
		{
			return -1;
		}

		//gli cerco un posto
		int i = 0;
		for(i=0;i<poltrone.length;i++)
		{
			if(poltrone[i].isLibera())
			{
				poltrone[i].prenota(ilPrenotante);
				prenotati++;
				return i;
			}
		}

		//questo non deve accadere
		return -1000;
	}

	/**
	* Cancella la prenotazione a nome ilCancellante. Se esiste una prenotazione
	* a nome ilCancellante ha successo, altrimenti fallisce. Ritorna true
	* in caso di successo, false altrimenti.
	*/
	public boolean cancella(String ilCancellante)
	{
		int posizione = esistePrenotazione(ilCancellante);
		if(posizione == -1)
		{
			return false;
		}

		if(poltrone[posizione].cancellaPrenotazione(ilCancellante))
		{
			prenotati--;
			return true;
		}
		return false;
	}

	/**
	* Ritorna il numero di posti liberi in sala.
	*/
	public int postiLiberi()
	{
		return poltrone.length-prenotati;
	}

	/**
	* Ritorna la capienza della sala.
	*/
	public int capienza()
	{
		return poltrone.length;
	}

	/**
	* Cerca la poltrona prenotata a nome ilPrenotato. Ritorna il numero di
	* poltrona prenotata se esiste una prenotazione a nome ilPrenotato, -1
	* se non c'e' una prenotazione a tale nome.
	*/
	public int esistePrenotazione(String ilPrenotato)
	{
		int i = 0;
		int occupati = 0;
		for(i=0;i<poltrone.length && occupati < prenotati;i++)
		{
			String tmpNome = poltrone[i].prenotata();
			if(tmpNome == null)
			{
				continue;
			}
			occupati++;
			if(tmpNome.equals(ilPrenotato))
			{
				return i;
			}
		}
		return -1;
	}

	/**
	* Fornisce la versione stringhificata dell'oggetto SalaCinema. Restituisce
	* la capienza, il numero di posti liberi e lo stato delle singole poltrone.
	*/
	public String toString()
	{
		String retval = "Cinema con capienza " + poltrone.length + "\n";
		retval = retval.concat(prenotati + " posti prenotati allo stato attuale\n");
		int i = 0;
		for(i=0;i<poltrone.length;i++)
		{
			retval = retval.concat("Posto " + i + poltrone[i].toString() + "; ");
		}
		return retval;
	}
}
